@@ -1,6 +1,7 @@
 # Copyright 2021 Cognite AS
 
 import numpy as np
+import numpy.typing as npt
 import pandas as pd
 
 from scipy.stats import shapiro
@@ -10,7 +11,7 @@ from ..type_check import check_types
 from ..validations import validate_series_has_time_index, validate_series_is_not_empty
 
 
-def _generate_step_series(index: pd.Index, is_gap: np.array) -> pd.Series:
+def _generate_step_series(index: pd.Index, is_gap: npt.NDArray) -> pd.Series:
     """Construct a step-wise time series (with 0-1 values) from an index and a boolean list"""
 
     assert len(index) == len(is_gap) + 1
